<template>
  <Dialog :title="dialogTitle" v-model="dialogVisible">
    <el-form
      ref="formRef"
      :model="formData"
      :rules="formRules"
      label-width="100px"
      v-loading="formLoading"
    >
      <el-form-item label="主机名称" prop="hostName">
        <el-input v-model="formData.hostName" placeholder="请输入主机名称" />
      </el-form-item>
      <el-form-item label="服务器ip" prop="hostIp">
        <el-input v-model="formData.hostIp" placeholder="请输入服务器ip" />
      </el-form-item>
      <el-form-item label="盘符" prop="disk">
        <el-input v-model="formData.disk" placeholder="请输入盘符" />
      </el-form-item>
      <el-form-item label="磁盘名" prop="diskName">
        <el-input v-model="formData.diskName" placeholder="请输入磁盘名" />
      </el-form-item>
      <el-form-item label="总空间" prop="spaceTotal">
        <el-input v-model="formData.spaceTotal" placeholder="请输入总空间" />
      </el-form-item>
      <el-form-item label="已用空间" prop="spaceUsed">
        <el-input v-model="formData.spaceUsed" placeholder="请输入已用空间" />
      </el-form-item>
      <el-form-item label="可用空间" prop="spaceUsable">
        <el-input v-model="formData.spaceUsable" placeholder="请输入可用空间" />
      </el-form-item>
      <el-form-item label="空间使用比例" prop="spaceRatio">
        <el-input v-model="formData.spaceRatio" placeholder="请输入空间使用比例" />
      </el-form-item>
    </el-form>
    <template #footer>
      <el-button @click="submitForm" type="primary" :disabled="formLoading">确 定</el-button>
      <el-button @click="dialogVisible = false">取 消</el-button>
    </template>
  </Dialog>
</template>
<script setup lang="ts">
import { MonitorDiskApi, MonitorDiskVO } from '@/api/infra/monitordisk'

/** 磁盘监控日志 表单 */
defineOptions({ name: 'MonitorDiskForm' })

const { t } = useI18n() // 国际化
const message = useMessage() // 消息弹窗

const dialogVisible = ref(false) // 弹窗的是否展示
const dialogTitle = ref('') // 弹窗的标题
const formLoading = ref(false) // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用
const formType = ref('') // 表单的类型：create - 新增；update - 修改
const formData = ref({
  id: undefined,
  hostName: undefined,
  hostIp: undefined,
  disk: undefined,
  diskName: undefined,
  spaceTotal: undefined,
  spaceUsed: undefined,
  spaceUsable: undefined,
  spaceRatio: undefined,
})
const formRules = reactive({
  hostName: [{ required: true, message: '主机名称不能为空', trigger: 'blur' }],
  hostIp: [{ required: true, message: '服务器ip不能为空', trigger: 'blur' }],
})
const formRef = ref() // 表单 Ref

/** 打开弹窗 */
const open = async (type: string, id?: number) => {
  dialogVisible.value = true
  dialogTitle.value = t('action.' + type)
  formType.value = type
  resetForm()
  // 修改时，设置数据
  if (id) {
    formLoading.value = true
    try {
      formData.value = await MonitorDiskApi.getMonitorDisk(id)
    } finally {
      formLoading.value = false
    }
  }
}
defineExpose({ open }) // 提供 open 方法，用于打开弹窗

/** 提交表单 */
const emit = defineEmits(['success']) // 定义 success 事件，用于操作成功后的回调
const submitForm = async () => {
  // 校验表单
  await formRef.value.validate()
  // 提交请求
  formLoading.value = true
  try {
    const data = formData.value as unknown as MonitorDiskVO
    if (formType.value === 'create') {
      await MonitorDiskApi.createMonitorDisk(data)
      message.success(t('common.createSuccess'))
    } else {
      await MonitorDiskApi.updateMonitorDisk(data)
      message.success(t('common.updateSuccess'))
    }
    dialogVisible.value = false
    // 发送操作成功的事件
    emit('success')
  } finally {
    formLoading.value = false
  }
}

/** 重置表单 */
const resetForm = () => {
  formData.value = {
    id: undefined,
    hostName: undefined,
    hostIp: undefined,
    disk: undefined,
    diskName: undefined,
    spaceTotal: undefined,
    spaceUsed: undefined,
    spaceUsable: undefined,
    spaceRatio: undefined,
  }
  formRef.value?.resetFields()
}
</script>